@@ -139,37 +139,41 @@ class Client:
                 return ret, e
         else:
             return False, '未受支持的Backend'
+        
+    def put_from_cloud(self, url, bucket, bucket_name, timeout=10, file_ttl=-1):
+        # save to cache
+        task_id = 'tmp_file_{}_{}'.format(bucket, bucket_name)
+        ret = self.mq.publish(self.put_topic, {
+            'url': url,
+            'bucket': bucket,
+            'bucket_name': bucket_name,
+            'ttl': file_ttl
+        })
+        
+        if ret:
+            t = time.time()
+            while True:
+                if time.time() - t >= timeout:
+                    break
+                
+                resp = self.redis.get(task_id)
+                
+                if resp is not None and len(resp) > 0:
+                    resp = json.loads(resp)
+                    if resp['ret']:
+                        return True, '{}/{}'.format(bucket, bucket_name)
+                    else:
+                        return False, resp['err']
+                
+                time.sleep(1)
+        return False, '上传出错'
     
     def put(self, path, bucket, bucket_name, timeout=10, file_ttl=-1):
         ret, e = self.put_to_cloud(path, bucket, bucket_name)
         if ret:
-            # save to cache
-            task_id = 'tmp_file_{}_{}'.format(bucket, bucket_name)
-            ret = self.mq.publish(self.put_topic, {
-                'url': e,
-                'bucket': bucket,
-                'bucket_name': bucket_name,
-                'ttl': file_ttl
-            })
-            
-            if ret:
-                t = time.time()
-                while True:
-                    if time.time() - t >= timeout:
-                        break
-                    
-                    resp = self.redis.get(task_id)
-                    
-                    if resp is not None and len(resp) > 0:
-                        resp = json.loads(resp)
-                        if resp['ret']:
-                            return True, '{}/{}'.format(bucket, bucket_name)
-                        else:
-                            return False, resp['err']
-                    
-                    time.sleep(1)
+            ret, e = self.put_from_cloud(e, bucket, bucket_name, timeout, file_ttl)
                 
-        return False, e
+        return ret, e
     
     def get(self, path, url, force_copy=False, min_size=0, timeout=10):
         if '://' in url:
